..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

Application and CLI factory
---------------------------

.. automodule:: invenio_base.app
   :members:

WSGI factory
------------

.. automodule:: invenio_base.wsgi
   :members:

Signals
-------

.. automodule:: invenio_base.signals
   :members:
